Object.defineProperty(exports, '__esModule', { value: true });

const browser = require('@sentry/browser');
const svelte = require('svelte');
const core = require('@sentry/core');
const constants = require('./constants.js');

const defaultTrackComponentOptions

 = {
  trackInit: true,
  trackUpdates: true,
};

/**
 * Tracks the Svelte component's initialization and mounting operation as well as
 * updates and records them as spans.
 *
 * This function is injected automatically into your Svelte components' code
 * if you are using the withSentryConfig wrapper.
 *
 * Alternatively, you can call it yourself if you don't want to use the preprocessor.
 */
function trackComponent(options) {
  const mergedOptions = { ...defaultTrackComponentOptions, ...options };

  const customComponentName = mergedOptions.componentName;

  const componentName = `<${customComponentName || constants.DEFAULT_COMPONENT_NAME}>`;

  if (mergedOptions.trackInit) {
    recordInitSpan(componentName);
  }

  if (mergedOptions.trackUpdates) {
    recordUpdateSpans(componentName);
  }
}

function recordInitSpan(componentName) {
  const initSpan = core.startInactiveSpan({
    onlyIfParent: true,
    op: constants.UI_SVELTE_INIT,
    name: componentName,
    attributes: { [browser.SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: 'auto.ui.svelte' },
  });

  svelte.onMount(() => {
    initSpan.end();
  });
}

function recordUpdateSpans(componentName) {
  let updateSpan;
  svelte.beforeUpdate(() => {
    updateSpan = core.startInactiveSpan({
      onlyIfParent: true,
      op: constants.UI_SVELTE_UPDATE,
      name: componentName,
      attributes: { [browser.SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: 'auto.ui.svelte' },
    });
  });

  svelte.afterUpdate(() => {
    if (!updateSpan) {
      return;
    }
    updateSpan.end();
    updateSpan = undefined;
  });
}

exports.trackComponent = trackComponent;
//# sourceMappingURL=performance.js.map
